# Xi-CAM
[![PyPI](https://badgen.net/pypi/v/xicam)](https://pypi.org/project/xicam/)
[![License](https://badgen.net/pypi/license/xicam)](https://github.com/Xi-cam/Xi-cam)
[![Build Status](https://img.shields.io/travis/Xi-cam/Xi-cam/master.svg)](https://travis-ci.org/Xi-cam/Xi-cam)
[![Documentation Status](https://readthedocs.org/projects/xi-cam/badge/?version=latest)](https://xi-cam.readthedocs.io/en/latest/?badge=latest)
[![Test Coverage](https://img.shields.io/codecov/c/github/Xi-cam/Xi-cam/master.svg)](https://codecov.io/github/Xi-cam/Xi-cam?branch=master)
[![Slack Status](https://img.shields.io/badge/slack-@ronpandolfi/nikea-yellow.svg?logo=slack)](https://nikea.slack.com/messages/U7Q1N42F6)

Xi-cam is a graphical environment for synchrotron data analysis,
management, and visualization developed by the Advanced Light Source at
Lawrence Berkeley National Laboratory. This is a cross-platform
open-source Python 3 project licensed under BSD.

## Installation

The latest stable Xi-CAM is available on pypi

```bash
pip install xicam
```

For more information, see the [installation documentation](https://xi-cam.readthedocs.io/en/latest/install.html).

## Resources

* Documentation: https://xi-cam.readthedocs.io/en/latest
* Report an issue in Xi-CAM: [New Bug Report](https://github.com/Xi-CAM/Xi-cam/issues/new?labels=bug&template=bug_report.md)
